@@ -587,7 +587,7 @@ class PaLM(nn.Module):
         if exists(context):
             context = self.to_cross_attn_key_values(context)
             context = rearrange(context, 'b n (l r d) -> b n l r d', r = 2, l = len(self.layers))
-            cross_attn_key_values = tuple(tuple(tensor.unbind(dim = -2) for tensor in context.unbind(dim = -3)))
+            cross_attn_key_values = tuple(tensor.unbind(dim = -2) for tensor in context.unbind(dim = -3))
 
         # parallel attention / ff blocks, passing in finetuning loras
 
