@@ -641,8 +641,7 @@ class RLHFTrainer(nn.Module):
                 if self.is_enc_dec:
                     action_logits, values = self.actor_critic(
                         actions,
-                        prompt = states,
-
+                        prompt = states
                     )
                 else:
                     action_logits, values = self.actor_critic(
